<?php

return array(
	'label' => array('Zentrierter Featured-Block Ende ←', 'Erzeugt einen zentrierten Feature-Block (z.B. Weinlinie)'),
	'types' => array('content', 'module'),
    'contentCategory' => 'featured',
	'wrapper' => array(
		'type' => 'stop',
	),
	'fields' => array(),
);
